import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import { withStyles } from '@material-ui/core/styles';
import Drawer from '@material-ui/core/Drawer';
import CssBaseline from '@material-ui/core/CssBaseline';
import AppBar from '@material-ui/core/AppBar';
import LinearProgress from '@material-ui/core/LinearProgress';
import Toolbar from '@material-ui/core/Toolbar';
import List from '@material-ui/core/List';
import Typography from '@material-ui/core/Typography';
import Divider from '@material-ui/core/Divider';
import IconButton from '@material-ui/core/IconButton';
import MenuIcon from '@material-ui/icons/Menu';
import BookIcon from '@material-ui/icons/Book';
import ChevronLeftIcon from '@material-ui/icons/ChevronLeft';
import ChevronRightIcon from '@material-ui/icons/ChevronRight';
import ListItem from '@material-ui/core/ListItem';
import ListItemIcon from '@material-ui/core/ListItemIcon';
import ListItemText from '@material-ui/core/ListItemText';
import AttachFileIcon from '@material-ui/icons/AttachFile';
import CloudDownloadIcon from '@material-ui/icons/CloudDownload';
import Analysis from './Analysis';
import { isEmpty, analyzePoem } from '../Utils';

const drawerWidth = 240;

const styles = theme => ({
  root: {
    display: 'flex',
  },
  appBar: {
    transition: theme.transitions.create(['margin', 'width'], {
      easing: theme.transitions.easing.sharp,
      duration: theme.transitions.duration.leavingScreen,
    }),
  },
  appBarShift: {
    width: `calc(100% - ${drawerWidth}px)`,
    marginLeft: drawerWidth,
    transition: theme.transitions.create(['margin', 'width'], {
      easing: theme.transitions.easing.easeOut,
      duration: theme.transitions.duration.enteringScreen,
    }),
  },
  menuButton: {
    marginLeft: 12,
    marginRight: 20,
  },
  hide: {
    display: 'none',
  },
  drawer: {
    width: drawerWidth,
    flexShrink: 0,
  },
  drawerPaper: {
    width: drawerWidth,
  },
  drawerHeader: {
    display: 'flex',
    alignItems: 'center',
    padding: '0 8px',
    ...theme.mixins.toolbar,
    justifyContent: 'flex-end',
  },
  content: {
    flexGrow: 1,
    padding: theme.spacing(3),
    transition: theme.transitions.create('margin', {
      easing: theme.transitions.easing.sharp,
      duration: theme.transitions.duration.leavingScreen,
    }),
    marginLeft: -drawerWidth,
  },
  contentShift: {
    transition: theme.transitions.create('margin', {
      easing: theme.transitions.easing.easeOut,
      duration: theme.transitions.duration.enteringScreen,
    }),
    marginLeft: 0,
  },
});

class Main extends React.Component {

  constructor(props) {
    super(props);
    this.state = {
      open: false,
      operations: ["scansion", "enjambment", "entities"],
    };
  }

  handleDrawerOpen = () => {
    this.setState({ open: true });
  };

  handleDrawerClose = () => {
    this.setState({ open: false });
  };

  componentDidUpdate() {
    const { current, poems } = this.props;
    const poem = poems[current];
    const text = poem ? poem.text : null;
    const analysis = poem ? poem.analysis : {};
    if (isEmpty(analysis) && text) {
      analyzePoem(text,
                  this.state.operations,
                  data => this.props.updatePoem({...poem, analysis: data}));
    }
  }

  render() {
    const { classes, theme, current, poems } = this.props;
    const { open } = this.state;
    const poem = poems[current];
    const title = poem ? poem.title : "";
    const text = poem ? poem.text : "";
    const analysis = poem ? <Analysis poem={poem} /> : "To start, add a poem";
    return (
      <div className={classes.root}>
        <CssBaseline />
        <AppBar
          position="fixed"
          className={classNames(classes.appBar, {
            [classes.appBarShift]: open,
          })}
        >
          <Toolbar disableGutters={!open}>
            <IconButton
              color="inherit"
              aria-label="Open drawer"
              onClick={this.handleDrawerOpen}
              className={classNames(classes.menuButton, open && classes.hide)}
            >
              <MenuIcon />
            </IconButton>
            <Typography variant="h6" color="inherit" noWrap>
              PoetryLab: {title}
            </Typography>
          </Toolbar>
        </AppBar>
        <Drawer
          className={classes.drawer}
          variant="persistent"
          anchor="left"
          open={open}
          classes={{
            paper: classes.drawerPaper,
          }}
        >
          <div className={classes.drawerHeader}>
            <IconButton onClick={this.handleDrawerClose}>
              {theme.direction === 'ltr' ? <ChevronLeftIcon /> : <ChevronRightIcon />}
            </IconButton>
          </div>
          <Divider />
          <List>
            {this.props.poems.map(({title, _}, index) => (
              <ListItem button key={title} onClick={() => this.props.changeCurrent(index)}>
                <ListItemIcon><BookIcon /></ListItemIcon>
                <ListItemText primary={title} />
              </ListItem>
            ))}
          </List>
          <Divider />
          <List>
            <ListItem button key="Upload a zip">
              <ListItemIcon><AttachFileIcon /></ListItemIcon>
              <ListItemText primary="Upload a zip" />
            </ListItem>
            <ListItem button key="Download all">
              <ListItemIcon><CloudDownloadIcon /></ListItemIcon>
              <ListItemText primary="Download all" />
            </ListItem>
          </List>
        </Drawer>
        <main
          className={classNames(classes.content, {
            [classes.contentShift]: open,
          })}
        >
          <div className={classes.drawerHeader} />
           { analysis }
           { poem && isEmpty(poem.analysis) && text ? [<LinearProgress key="analyzing-progress" />, "Analyzing..."] : "" }
        </main>
      </div>
    );
  }
}

Main.propTypes = {
  classes: PropTypes.object.isRequired,
  theme: PropTypes.object.isRequired,
  poems: PropTypes.array.isRequired,
  current: PropTypes.number.isRequired,
  changeCurrent: PropTypes.func.isRequired,
  updatePoem: PropTypes.func.isRequired,
};

export default withStyles(styles, { withTheme: true })(Main);
